@@ -1,8 +1,6 @@
-use std::{error::Error, fmt::Debug};
-
-use ssh_cfg2::{SshConfig, SshConfigParser, SshHostConfig};
-
 use crate::database::FileDatabase;
+use ssh_cfg::{SshConfig, SshConfigParser, SshHostConfig};
+use std::fmt::Debug;
 
 #[derive(Debug)]
 pub struct SshGroupItem {
@@ -26,10 +24,8 @@ pub struct SshConfigStore {
 }
 
 impl SshConfigStore {
-    pub async fn new(db: &FileDatabase) -> Result<SshConfigStore, Box<dyn Error>> {
-        let ssh_config = SshConfigParser::parse_home()
-            .await
-            .expect("Failed to parse ~/.ssh/config");
+    pub async fn new(db: &FileDatabase) -> Result<SshConfigStore, ssh_cfg::Error> {
+        let ssh_config = SshConfigParser::parse_home().await?;
 
         let mut scs = SshConfigStore {
             config: ssh_config,
